@@ -1,34 +1,41 @@
-#![crate_type = "lib"]
-#![crate_name = "varinteger"]
+#![cfg_attr(feature = "nightly", deny(missing_docs))]
+#![cfg_attr(feature = "nightly", feature(external_doc))]
+#![cfg_attr(feature = "nightly", doc(include = "../README.md"))]
+#![cfg_attr(test, deny(warnings))]
 
+/// Returns how many bytes are needed to encode a value.
 pub fn length(value: u64) -> usize {
   if value < 128 {
-    return 1;
+    1
   } else if value < 16384 {
-    return 2;
+    2
   } else if value < 2097152 {
-    return 3;
+    3
   } else if value < 268435456 {
-    return 4;
+    4
   } else if value < 34359738368 {
-    return 5;
+    5
   } else if value < 4398046511104 {
-    return 6;
+    6
   } else if value < 562949953421312 {
-    return 7;
+    7
   } else if value < 72057594037927936 {
-    return 8;
+    8
   } else if value < 9223372036854775808 {
-    return 9;
+    9
   } else {
-    return 10;
+    10
   }
 }
 
+/// Encode a `u64` integer to the byte slice. Returns how many bytes were
+/// encoded.
 pub fn encode(value: u64, buf: &mut [u8]) -> usize {
   encode_with_offset(value, buf, 0)
 }
 
+/// Encode a `u64` integer at a specific offset in the byte slice. Returns how
+/// many bytes were encoded.
 pub fn encode_with_offset(value: u64, buf: &mut [u8], offset: usize) -> usize {
   let mut off = offset;
   let mut val = value;
@@ -43,10 +50,14 @@ pub fn encode_with_offset(value: u64, buf: &mut [u8], offset: usize) -> usize {
   off + 1 - offset
 }
 
+/// Decode a byte slice into a `u64` integer. Returns how many bytes were
+/// decoded.
 pub fn decode(buf: &[u8], value: &mut u64) -> usize {
   return decode_with_offset(buf, 0, value);
 }
 
+/// Decode a byte slice into a `u64` integer at a specific offset. Returns how
+/// many bytes were decoded.
 pub fn decode_with_offset(buf: &[u8], offset: usize, value: &mut u64) -> usize {
   let mut val = 0 as u64;
   let mut fac = 1 as u64;
@@ -67,14 +78,19 @@ pub fn decode_with_offset(buf: &[u8], offset: usize, value: &mut u64) -> usize {
   off - offset
 }
 
+/// Returns how many bytes are needed to encode a value.
 pub fn signed_length(value: i64) -> usize {
   length(unsign(value))
 }
 
+/// Encode a `i64` (signed) integer at a specific offset in the byte slice.
+/// Returns how many bytes were encoded.
 pub fn signed_encode(value: i64, buf: &mut [u8]) -> usize {
   encode_with_offset(unsign(value), buf, 0)
 }
 
+/// Encode a `i64` (signed) integer at a specific offset in the byte slice.
+/// Returns how many bytes were encoded.
 pub fn signed_encode_with_offset(
   value: i64,
   buf: &mut [u8],
@@ -83,10 +99,14 @@ pub fn signed_encode_with_offset(
   encode_with_offset(unsign(value), buf, offset)
 }
 
+/// Decode a byte slice into a `i64` (signed) integer.  Returns how many bytes
+/// were decoded.
 pub fn signed_decode(buf: &[u8], value: &mut i64) -> usize {
   signed_decode_with_offset(buf, 0, value)
 }
 
+/// Decode a byte slice into a `i64` (signed) integer at a specific offset.
+/// Returns how many bytes were decoded.
 pub fn signed_decode_with_offset(
   buf: &[u8],
   offset: usize,
@@ -98,6 +118,7 @@ pub fn signed_decode_with_offset(
   off
 }
 
+/// Convert an `i64` into a `u64`.
 fn unsign(value: i64) -> u64 {
   if value >= 0 {
     (value * 2) as u64
@@ -106,6 +127,7 @@ fn unsign(value: i64) -> u64 {
   }
 }
 
+/// Convert a `u64` into a `i64`.
 fn sign(value: u64) -> i64 {
   if value & 1 != 0 {
     -(((value + 1) / 2) as i64)
